<template>
  <div v-show="visible">
    <a-row :gutter="48" slot="extra">
      <a-col :md="48" :sm="48">
        <span class="table-page-search-submitButtons" style="float: right">
          <a-button style="margin-left: 8px" @click="handleCancel()">返回</a-button>
        </span>
      </a-col>
    </a-row>
    <title-divider title="设备信息" width="90px"></title-divider>
    <detail-list title="" :col="3">
      <detail-list-item term="设备新号">{{ model.no }}</detail-list-item>
      <detail-list-item term="设备旧号">{{ model.zbh }}</detail-list-item>
      <detail-list-item term="型号">{{ model.model }}</detail-list-item>
      <detail-list-item term="设备名称">{{ model.name }}</detail-list-item>
    </detail-list>
    <title-divider title="保养信息" width="90px"></title-divider>
    <div class="table-operator" style="margin-bottom:8px;">
      <a-button type="primary" @click="handleAdd">
        <a-icon type="plus"/>
        添加
      </a-button>
      <a-button style="margin-left:8px;" type="primary" @click="handleSbSelect">
        <a-icon type="plus"/>
        复制
      </a-button>
      <a-button style="margin-left:8px;" type="primary" @click="doImport">
        <a-icon type="upload"/>
        新增导入
      </a-button>
      <!--      <a-button style="margin-left: 8px" type="primary" icon="download" @click="doExport">导出</a-button>-->
    </div>
    <a-table
      :data-source="data"
      :columns="columns"
      tableLayout="auto"
      rowKey="id">
      <span slot="action" slot-scope="record">
        <template>
          <a v-if="$auth('sb-infos-edit')" @click="handleView(record)">查看</a>
          <a-divider type="vertical" />
          <a v-if="$auth('sb-infos-edit')" @click="handleEdit(record)">修改</a>
          <a-divider type="vertical" />
          <a-popconfirm v-if="$auth('sb-infos-del')" title="是否要删除该条数据？" @confirm="batchDelete(record.id)">
            <a>删除</a>
          </a-popconfirm>
          <a-divider type="vertical" />
          <a @click="handleCopy(record)">复制</a>
          <a-divider type="vertical" />
          <a @click="handleGenerate(record)">插入任务</a>
        </template>
      </span>
    </a-table>
    <base-form ref="baseModal" :check-type="checkType" @ok="handleOk"/>
    <base-form-insert ref="baseModalInsert" @ok="handleOk"/>
    <detail ref="detailModal"/>
    <sb-info-select-modal :type="'radio'" ref="sbInfoSelectModal" @selected="handleSbSelected"/>
    <import-form-add ref="importModal" @ok="handleOk"/>
  </div>
</template>

<script>
import DetailList from '@/components/tools/DetailList'
import {
  queryCheckStandard,
  deleteCheckStandards,
  exportCheckStandard,
  fetchCheckStandard,
  copy
} from '@/api/check/checkstandard'
import BaseForm from './BaseForm'
import BaseFormInsert from './BaseFormInsert'
import Detail from './Detail'
import SbInfoSelectModal from '@/views/sb/info/modules/SbInfoSelectModal'
import ImportFormAdd from '@/views/check/checkstandard/modules/ImportFormAdd'
const DetailListItem = DetailList.Item

export default {
  name: 'DetailSbCheck',
  components: {
    DetailList,
    DetailListItem,
    BaseForm,
    Detail,
    SbInfoSelectModal,
    BaseFormInsert,
    ImportFormAdd
  },
  props: {
    /**
     * 检查类型： 1-点检 2-巡检
     */
    checkType: {
      type: Number,
      default: 2
    }
  },
  data () {
    return {
      confirmLoading: false,
      mdl: {},
      model: {
        'id': null,
        'modelId': null,
        'no': null,
        'zbh': null,
        'name': null,
        'nameModel': null,
        'unit': null,
        'level': null,
        'useType': null
      },
      modalTitle: null,
      visible: false,
      typeMap: {},
      actionTypeMap: {},
      // 表头
      columns: [
        {
          title: '序号',
          dataIndex: 'index',
          customRender: (text, record, index) => {
            return index + 1
          }
        },
        {
          title: '检查部位',
          dataIndex: 'partName'
        },
        {
          title: '名称',
          dataIndex: 'name',
          width: '300px'
        },
        {
          title: '周期',
          dataIndex: 'periodType',
          customRender: (text, record, index) => {
            return record.period + this.BaseTool.Table.getMapText(this.periodTypeMap, text)
          }
        },
   /*     {
          title: '动作类型',
          dataIndex: 'actionType',
          customRender: (text, record, index) => {
            return this.BaseTool.Table.getMapText(this.actionTypeMap, text)
          }
        },*/
        {
          title: '标准工时',
          dataIndex: 'standardHours'
        },
        {
          title: '操作',
          key: 'action',
          checked: true,
          align: 'center',
          // fixed: 'right',
          scopedSlots: { customRender: 'action' }
        }
      ],
      data: []
    }
  },
  created () {
    // 下拉框map
    this.typeMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.CHECK_STANDARD_TYPE)
    this.periodTypeMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.CHECK_PLAN_PERIOD_TYPE)
    this.actionTypeMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.CHECK_PLAN_ACTION_TYPE)
  },
  methods: {
    base (record) {
      this.visible = true
      this.model = record
      this.modalTitle = '详情2'
      queryCheckStandard({ sbId: record.id, type: this.checkType }).then(res => {
        this.data = res.data
      })
    },
    handleOk () {
      queryCheckStandard({ sbId: this.model.id, type: this.checkType }).then(res => {
        this.data = res.data
      })
    },
    handleAdd () {
      const modal = this.$refs.baseModal
      modal.base(null, this.model.id)
    },
    handleView (record) {
      fetchCheckStandard({ id: record.id }).then(res => {
        const modal = this.$refs.detailModal
        res.data.partName = record.partName
        modal.base(res.data)
      })
    },
    handleEdit (record) {
      fetchCheckStandard({ id: record.id }).then(res => {
        const modal = this.$refs.baseModal
        res.data.sbNo = this.model.no
        modal.base(res.data, this.model.id)
      })
    },
    handleCopy (record) {
      const modal = this.$refs.baseModal
      const data = record
      data.id = null
      modal.base(data)
    },
    handleGenerate (record) {
      const modal = this.$refs.baseModalInsert
      modal.base(null, record.id)
    },
    handleCancel () {
      this.visible = false
      this.confirmLoading = false
      this.$emit('ok')
    },
    batchDelete (id) {
      let ids = []
      if (this.BaseTool.String.isBlank(id)) {
        if (length === 0) {
          this.$message.info('请选择要删除的记录')
          return
        }
        ids = this.selectedRows.map(item => item.id)
      } else {
        ids = [id]
      }
      deleteCheckStandards(ids).then(res => {
        this.$message.info('删除成功')
        this.handleOk()
      })
    },
    doExport () {
      const parameter = {
        ...this.queryParam
      }
      parameter.modelId = this.model.id
      exportCheckStandard(parameter).then(file => {
        this.BaseTool.UPLOAD.downLoadExportExcel(file)
      })
    },
    doImport () {
      this.$refs.importModal.base(this.model.no)
    },
    handleSbSelect () {
      this.$refs.sbInfoSelectModal.base()
    },
    handleSbSelected (keys, rows) {
      const [ key ] = keys
      const [ row ] = rows
      // 日期处理
      copy({ sbId: this.model.id, copySbId: row.id })
        .then((response) => {
          this.$message.info(response.data)
          this.handleOk()
        }).catch(() => {
          this.confirmLoading = false
        })
    }
  }
}
</script>
